"""
ScrapyX namespace package.

This is a PEP 420 namespace package that provides a common namespace
for scrapyx-related packages such as:
- scrapyx-core
- scrapyx-mw
- etc.
"""

__version__ = "0.1.0"

